@@ -10,8 +10,8 @@ Net::MBE - Perl library to access Mailboxes Etc (MBE) online webservices.
 
     my $mbe = Net::MBE->new({
         system => 'IT',
-        Username => 'XXXXX',
-        Passphrase => 'YYYYYYYY',
+        username => 'XXXXX',
+        passphrase => 'YYYYYYYY',
     });
 
     my $dest = Net::MBE::DestinationInfo->new({
@@ -68,7 +68,7 @@ package Net::MBE {
     use Arthas::Defaults::520;
     use version;
 
-    our $VERSION = qv("v0.2.1");
+    our $VERSION = qv("v0.2.2");
 
 	#$SOAP::Constants::DEFAULT_HTTP_CONTENT_TYPE = 'text/xml';
 	#$SOAP::Constants::DO_NOT_USE_CHARSET = 1;
@@ -113,7 +113,7 @@ package Net::MBE {
                 # ],
                 default_headers => HTTP::Headers->new(
                     'Content-type', 'text/xml; charset=utf-8', # MBE won't accept application/soap
-                    'Authorization', 'Basic '.encode_base64($args->{Username} . ':' . $args->{Passphrase})
+                    'Authorization', 'Basic '.encode_base64($args->{username} . ':' . $args->{passphrase})
                 ),
             ],
             #wsdl => $args->{endpoint},
